/*

Java bindings for the Unicorn Emulator Engine

Copyright(c) 2015 Chris Eagle

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
version 2 as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

package unicorn;

public interface X86Regs {
   public static final int UC_X86_REG_INVALID = 0;
   public static final int UC_X86_REG_AH = 1;
   public static final int UC_X86_REG_AL = 2;
   public static final int UC_X86_REG_AX = 3;
   public static final int UC_X86_REG_BH = 4;
   public static final int UC_X86_REG_BL = 5;
   public static final int UC_X86_REG_BP = 6;
   public static final int UC_X86_REG_BPL = 7;
   public static final int UC_X86_REG_BX = 8;
   public static final int UC_X86_REG_CH = 9;
   public static final int UC_X86_REG_CL = 10;
   public static final int UC_X86_REG_CS = 11;
   public static final int UC_X86_REG_CX = 12;
   public static final int UC_X86_REG_DH = 13;
   public static final int UC_X86_REG_DI = 14;
   public static final int UC_X86_REG_DIL = 15;
   public static final int UC_X86_REG_DL = 16;
   public static final int UC_X86_REG_DS = 17;
   public static final int UC_X86_REG_DX = 18;
   public static final int UC_X86_REG_EAX = 19;
   public static final int UC_X86_REG_EBP = 20;
   public static final int UC_X86_REG_EBX = 21;
   public static final int UC_X86_REG_ECX = 22;
   public static final int UC_X86_REG_EDI = 23;
   public static final int UC_X86_REG_EDX = 24;
   public static final int UC_X86_REG_EFLAGS = 25;
   public static final int UC_X86_REG_EIP = 26;
   public static final int UC_X86_REG_EIZ = 27;
   public static final int UC_X86_REG_ES = 28;
   public static final int UC_X86_REG_ESI = 29;
   public static final int UC_X86_REG_ESP = 30;
   public static final int UC_X86_REG_FPSW = 31;
   public static final int UC_X86_REG_FS = 32;
   public static final int UC_X86_REG_GS = 33;
   public static final int UC_X86_REG_IP = 34;
   public static final int UC_X86_REG_RAX = 35;
   public static final int UC_X86_REG_RBP = 36;
   public static final int UC_X86_REG_RBX = 37;
   public static final int UC_X86_REG_RCX = 38;
   public static final int UC_X86_REG_RDI = 39;
   public static final int UC_X86_REG_RDX = 40;
   public static final int UC_X86_REG_RIP = 41;
   public static final int UC_X86_REG_RIZ = 42;
   public static final int UC_X86_REG_RSI = 43;
   public static final int UC_X86_REG_RSP = 44;
   public static final int UC_X86_REG_SI = 45;
   public static final int UC_X86_REG_SIL = 46;
   public static final int UC_X86_REG_SP = 47;
   public static final int UC_X86_REG_SPL = 48;
   public static final int UC_X86_REG_SS = 49;
   public static final int UC_X86_REG_CR0 = 50;
   public static final int UC_X86_REG_CR1 = 51;
   public static final int UC_X86_REG_CR2 = 52;
   public static final int UC_X86_REG_CR3 = 53;
   public static final int UC_X86_REG_CR4 = 54;
   public static final int UC_X86_REG_CR5 = 55;
   public static final int UC_X86_REG_CR6 = 56;
   public static final int UC_X86_REG_CR7 = 57;
   public static final int UC_X86_REG_CR8 = 58;
   public static final int UC_X86_REG_CR9 = 59;
   public static final int UC_X86_REG_CR10 = 60;
   public static final int UC_X86_REG_CR11 = 61;
   public static final int UC_X86_REG_CR12 = 62;
   public static final int UC_X86_REG_CR13 = 63;
   public static final int UC_X86_REG_CR14 = 64;
   public static final int UC_X86_REG_CR15 = 65;
   public static final int UC_X86_REG_DR0 = 66;
   public static final int UC_X86_REG_DR1 = 67;
   public static final int UC_X86_REG_DR2 = 68;
   public static final int UC_X86_REG_DR3 = 69;
   public static final int UC_X86_REG_DR4 = 70;
   public static final int UC_X86_REG_DR5 = 71;
   public static final int UC_X86_REG_DR6 = 72;
   public static final int UC_X86_REG_DR7 = 73;
   public static final int UC_X86_REG_DR8 = 74;
   public static final int UC_X86_REG_DR9 = 75;
   public static final int UC_X86_REG_DR10 = 76;
   public static final int UC_X86_REG_DR11 = 77;
   public static final int UC_X86_REG_DR12 = 78;
   public static final int UC_X86_REG_DR13 = 79;
   public static final int UC_X86_REG_DR14 = 80;
   public static final int UC_X86_REG_DR15 = 81;
   public static final int UC_X86_REG_FP0 = 82;
   public static final int UC_X86_REG_FP1 = 83;
   public static final int UC_X86_REG_FP2 = 84;
   public static final int UC_X86_REG_FP3 = 85;
   public static final int UC_X86_REG_FP4 = 86;
   public static final int UC_X86_REG_FP5 = 87;
   public static final int UC_X86_REG_FP6 = 88;
   public static final int UC_X86_REG_FP7 = 89;
   public static final int UC_X86_REG_K0 = 90;
   public static final int UC_X86_REG_K1 = 91;
   public static final int UC_X86_REG_K2 = 92;
   public static final int UC_X86_REG_K3 = 93;
   public static final int UC_X86_REG_K4 = 94;
   public static final int UC_X86_REG_K5 = 95;
   public static final int UC_X86_REG_K6 = 96;
   public static final int UC_X86_REG_K7 = 97;
   public static final int UC_X86_REG_MM0 = 98;
   public static final int UC_X86_REG_MM1 = 99;
   public static final int UC_X86_REG_MM2 = 100;
   public static final int UC_X86_REG_MM3 = 101;
   public static final int UC_X86_REG_MM4 = 102;
   public static final int UC_X86_REG_MM5 = 103;
   public static final int UC_X86_REG_MM6 = 104;
   public static final int UC_X86_REG_MM7 = 105;
   public static final int UC_X86_REG_R8 = 106;
   public static final int UC_X86_REG_R9 = 107;
   public static final int UC_X86_REG_R10 = 108;
   public static final int UC_X86_REG_R11 = 109;
   public static final int UC_X86_REG_R12 = 110;
   public static final int UC_X86_REG_R13 = 111;
   public static final int UC_X86_REG_R14 = 112;
   public static final int UC_X86_REG_R15 = 113;
   public static final int UC_X86_REG_ST0 = 114;
   public static final int UC_X86_REG_ST1 = 115;
   public static final int UC_X86_REG_ST2 = 116;
   public static final int UC_X86_REG_ST3 = 117;
   public static final int UC_X86_REG_ST4 = 118;
   public static final int UC_X86_REG_ST5 = 119;
   public static final int UC_X86_REG_ST6 = 120;
   public static final int UC_X86_REG_ST7 = 121;
   public static final int UC_X86_REG_XMM0 = 122;
   public static final int UC_X86_REG_XMM1 = 123;
   public static final int UC_X86_REG_XMM2 = 124;
   public static final int UC_X86_REG_XMM3 = 125;
   public static final int UC_X86_REG_XMM4 = 126;
   public static final int UC_X86_REG_XMM5 = 127;
   public static final int UC_X86_REG_XMM6 = 128;
   public static final int UC_X86_REG_XMM7 = 129;
   public static final int UC_X86_REG_XMM8 = 130;
   public static final int UC_X86_REG_XMM9 = 131;
   public static final int UC_X86_REG_XMM10 = 132;
   public static final int UC_X86_REG_XMM11 = 133;
   public static final int UC_X86_REG_XMM12 = 134;
   public static final int UC_X86_REG_XMM13 = 135;
   public static final int UC_X86_REG_XMM14 = 136;
   public static final int UC_X86_REG_XMM15 = 137;
   public static final int UC_X86_REG_XMM16 = 138;
   public static final int UC_X86_REG_XMM17 = 139;
   public static final int UC_X86_REG_XMM18 = 140;
   public static final int UC_X86_REG_XMM19 = 141;
   public static final int UC_X86_REG_XMM20 = 142;
   public static final int UC_X86_REG_XMM21 = 143;
   public static final int UC_X86_REG_XMM22 = 144;
   public static final int UC_X86_REG_XMM23 = 145;
   public static final int UC_X86_REG_XMM24 = 146;
   public static final int UC_X86_REG_XMM25 = 147;
   public static final int UC_X86_REG_XMM26 = 148;
   public static final int UC_X86_REG_XMM27 = 149;
   public static final int UC_X86_REG_XMM28 = 150;
   public static final int UC_X86_REG_XMM29 = 151;
   public static final int UC_X86_REG_XMM30 = 152;
   public static final int UC_X86_REG_XMM31 = 153;
   public static final int UC_X86_REG_YMM0 = 154;
   public static final int UC_X86_REG_YMM1 = 155;
   public static final int UC_X86_REG_YMM2 = 156;
   public static final int UC_X86_REG_YMM3 = 157;
   public static final int UC_X86_REG_YMM4 = 158;
   public static final int UC_X86_REG_YMM5 = 159;
   public static final int UC_X86_REG_YMM6 = 160;
   public static final int UC_X86_REG_YMM7 = 161;
   public static final int UC_X86_REG_YMM8 = 162;
   public static final int UC_X86_REG_YMM9 = 163;
   public static final int UC_X86_REG_YMM10 = 164;
   public static final int UC_X86_REG_YMM11 = 165;
   public static final int UC_X86_REG_YMM12 = 166;
   public static final int UC_X86_REG_YMM13 = 167;
   public static final int UC_X86_REG_YMM14 = 168;
   public static final int UC_X86_REG_YMM15 = 169;
   public static final int UC_X86_REG_YMM16 = 170;
   public static final int UC_X86_REG_YMM17 = 171;
   public static final int UC_X86_REG_YMM18 = 172;
   public static final int UC_X86_REG_YMM19 = 173;
   public static final int UC_X86_REG_YMM20 = 174;
   public static final int UC_X86_REG_YMM21 = 175;
   public static final int UC_X86_REG_YMM22 = 176;
   public static final int UC_X86_REG_YMM23 = 177;
   public static final int UC_X86_REG_YMM24 = 178;
   public static final int UC_X86_REG_YMM25 = 179;
   public static final int UC_X86_REG_YMM26 = 180;
   public static final int UC_X86_REG_YMM27 = 181;
   public static final int UC_X86_REG_YMM28 = 182;
   public static final int UC_X86_REG_YMM29 = 183;
   public static final int UC_X86_REG_YMM30 = 184;
   public static final int UC_X86_REG_YMM31 = 185;
   public static final int UC_X86_REG_ZMM0 = 186;
   public static final int UC_X86_REG_ZMM1 = 187;
   public static final int UC_X86_REG_ZMM2 = 188;
   public static final int UC_X86_REG_ZMM3 = 189;
   public static final int UC_X86_REG_ZMM4 = 190;
   public static final int UC_X86_REG_ZMM5 = 191;
   public static final int UC_X86_REG_ZMM6 = 192;
   public static final int UC_X86_REG_ZMM7 = 193;
   public static final int UC_X86_REG_ZMM8 = 194;
   public static final int UC_X86_REG_ZMM9 = 195;
   public static final int UC_X86_REG_ZMM10 = 196;
   public static final int UC_X86_REG_ZMM11 = 197;
   public static final int UC_X86_REG_ZMM12 = 198;
   public static final int UC_X86_REG_ZMM13 = 199;
   public static final int UC_X86_REG_ZMM14 = 200;
   public static final int UC_X86_REG_ZMM15 = 201;
   public static final int UC_X86_REG_ZMM16 = 202;
   public static final int UC_X86_REG_ZMM17 = 203;
   public static final int UC_X86_REG_ZMM18 = 204;
   public static final int UC_X86_REG_ZMM19 = 205;
   public static final int UC_X86_REG_ZMM20 = 206;
   public static final int UC_X86_REG_ZMM21 = 207;
   public static final int UC_X86_REG_ZMM22 = 208;
   public static final int UC_X86_REG_ZMM23 = 209;
   public static final int UC_X86_REG_ZMM24 = 210;
   public static final int UC_X86_REG_ZMM25 = 211;
   public static final int UC_X86_REG_ZMM26 = 212;
   public static final int UC_X86_REG_ZMM27 = 213;
   public static final int UC_X86_REG_ZMM28 = 214;
   public static final int UC_X86_REG_ZMM29 = 215;
   public static final int UC_X86_REG_ZMM30 = 216;
   public static final int UC_X86_REG_ZMM31 = 217;
   public static final int UC_X86_REG_R8B = 218;
   public static final int UC_X86_REG_R9B = 219;
   public static final int UC_X86_REG_R10B = 220;
   public static final int UC_X86_REG_R11B = 221;
   public static final int UC_X86_REG_R12B = 222;
   public static final int UC_X86_REG_R13B = 223;
   public static final int UC_X86_REG_R14B = 224;
   public static final int UC_X86_REG_R15B = 225;
   public static final int UC_X86_REG_R8D = 226;
   public static final int UC_X86_REG_R9D = 227;
   public static final int UC_X86_REG_R10D = 228;
   public static final int UC_X86_REG_R11D = 229;
   public static final int UC_X86_REG_R12D = 230;
   public static final int UC_X86_REG_R13D = 231;
   public static final int UC_X86_REG_R14D = 232;
   public static final int UC_X86_REG_R15D = 233;
   public static final int UC_X86_REG_R8W = 234;
   public static final int UC_X86_REG_R9W = 235;
   public static final int UC_X86_REG_R10W = 236;
   public static final int UC_X86_REG_R11W = 237;
   public static final int UC_X86_REG_R12W = 238;
   public static final int UC_X86_REG_R13W = 239;
   public static final int UC_X86_REG_R14W = 240;
   public static final int UC_X86_REG_R15W = 241;
   public static final int UC_X86_REG_ENDING = 242;
}
